====================
Django Richtext Blog
====================

A django app that implements a blog with the features we've grown accustomed
to.

Features
========

* Rich text editing implemented with TinyMCE
* Full image upload support via TimyMCE using grapelli and filebrowser modules
* Support for post tagging
* Support for comments in posts
* Code syntax highlighting with pygments
* Comment spam prevention through integration with djamgo-simple-captcha
* Atom and RSS feed support
* Templates included to provide examples of how django-richtext-blog can be
  used
* SEO optimised urls for posts and tags
